local FixehTipVersion = "2.7.4"

local TooltipLocations = {
	Mouse = {
		"BOTTOM",
		"BOTTOMLEFT",
		"BOTTOMRIGHT",
	},
	Default = {
		"BOTTOMRIGHT",
		"BOTTOMLEFT",
		"TOPRIGHT",
		"TOPLEFT",
		"RIGHT",
		"LEFT",
		"TOP",
		"BOTTOM",
		"CENTER",
	},
}

local FixehTipConfig = {
	name = format("FixehTip %s", FixehTipVersion),
	type = "group",
	childGroups = "tab",
	args = {
		anchorControl = {
			name = "Anchor control",
			type = "group",
			order = 1,
			args = {
				defaultAnchorControl = {
					name = "Default anchor",
					type = "group",
					order = 1,
					args = {
						defaultAnchor = {
							name = "Default anchor location",
							type = "select",
							order = 1,
							values = TooltipLocations.Default,
							set = function(_, location)
								FixehTipSV.defaultAnchorLocation = TooltipLocations.Default[location]
							end,
							get = function()
								for k, v in next, TooltipLocations.Default do
									if (FixehTipSV.defaultAnchorLocation == v) then
										return k
									end
								end
							end,
						},
						defaultAnchorX = {
							name = "Default anchor X",
							type = "input",
							order = 2,
							set = function(_, input)
								FixehTipSV.defaultAnchorX = input
							end,
							get = function()
								return FixehTipSV.defaultAnchorX
							end,
						},
						defaultAnchorY = {
							name = "Default anchor Y",
							type = "input",
							order = 3,
							set = function(_, input)
								FixehTipSV.defaultAnchorY = input
							end,
							get = function()
								return FixehTipSV.defaultAnchorY
							end,
						},
					},
				},
				mouseAnchorControl = {
					name = "Mouse anchor",
					type = "group",
					order = 2,
					args = {
						mouseAnchor = {
							name = "Mouse anchor",
							desc = "Tooltip on mouse cursor.",
							type = "toggle",
							order = 1,
							set = function()
								if (FixehTipSV.mouseAnchor) then
									FixehTipSV.mouseAnchor = nil
								else
									FixehTipSV.mouseAnchor = true
								end
							end,
							get = function()
								return FixehTipSV.mouseAnchor
							end,
						},
						mouseAnchorLocation = {
							name = "Mouse anchor location",
							type = "select",
							order = 2,
							values = TooltipLocations.Mouse,
							set = function(_, location)
								FixehTipSV.mouseAnchorLocation = TooltipLocations.Mouse[location]
							end,
							get = function()
								for k, v in next, TooltipLocations.Mouse do
									if (FixehTipSV.mouseAnchorLocation == v) then
										return k
									end
								end
							end,
						},
						mouseAnchorLocationX = {
							name = "Mouse anchor X",
							type = "input",
							order = 3,
							set = function(_, input)
								FixehTipSV.mouseAnchorX = input
							end,
							get = function()
								return FixehTipSV.mouseAnchorX
							end,
						},
						mouseAnchorLocationY = {
							name = "Mouse anchor Y",
							type = "input",
							order = 4,
							set = function(_, input)
								FixehTipSV.mouseAnchorY = input
							end,
							get = function()
								return FixehTipSV.mouseAnchorY
							end,
						},
					},
				},
				healthAnchorControl = {
					name = "Health anchor",
					type = "group",
					order = 3,
					args = {
						healthAnchor = {
							name = "Health inside",
							type = "toggle",
							order = 1,
							set = function()
								if (FixehTipSV.healthInside) then
									FixehTipSV.healthInside = nil
								else
									FixehTipSV.healthInside = true
								end
							end,
							get = function()
								return FixehTipSV.healthInside
							end,
						},
					},
				},
			},
		},
		appearance = {
			name = "Appearance",
			type = "group",
			order = 2,
			args = {
				text = {
					name = "Text ",
					type = "group",
					order = 1,
					args = {
						guildRank = {
							name = "Guild rank",
							desc = "Adds guild ranks next to guild names.",
							type = "toggle",
							order = 1,
							set = function()
								if (FixehTipSV.guildRank) then
									FixehTipSV.guildRank = nil
								else
									FixehTipSV.guildRank = true
								end
							end,
							get = function()
								return FixehTipSV.guildRank
							end,
						},
						titleText = {
							name = "Hide player title",
							type = "toggle",
							order = 2,
							set = function()
								if (FixehTipSV.hidePlayerTitle) then
									FixehTipSV.hidePlayerTitle = nil
								else
									FixehTipSV.hidePlayerTitle = true
								end
							end,
							get = function()
								return FixehTipSV.hidePlayerTitle
							end,
						},
						serverText = {
							name = "Hide player server",
							type = "toggle",
							order = 3,
							set = function()
								if (FixehTipSV.hidePlayerServer) then
									FixehTipSV.hidePlayerServer = nil
								else
									FixehTipSV.hidePlayerServer = true
								end
							end,
							get = function()
								return FixehTipSV.hidePlayerServer
							end,
						},
						raceText = {
							name = "Hide player race",
							type = "toggle",
							order = 4,
							set = function()
								if (FixehTipSV.hidePlayerRace) then
									FixehTipSV.hidePlayerRace = nil
								else
									FixehTipSV.hidePlayerRace = true
								end
							end,
							get = function()
								return FixehTipSV.hidePlayerRace
							end,
						},
						pvpText = {
							name = "Hide PvP",
							desc = "Hides the PvP text on PvP flagged units.",
							type = "toggle",
							order = 5,
							set = function()
								if (FixehTipSV.hidePvPText) then
									FixehTipSV.hidePvPText = nil
								else
									FixehTipSV.hidePvPText = true
								end
							end,
							get = function()
								return FixehTipSV.hidePvPText
							end,
						},
						factionText = {
							name = "Hide faction",
							desc = "Hides the Horde and Alliance text on units.",
							type = "toggle",
							order = 6,
							set = function()
								if (FixehTipSV.hideFactionText) then
									FixehTipSV.hideFactionText = nil
								else
									FixehTipSV.hideFactionText = true
								end
							end,
							get = function()
								return FixehTipSV.hideFactionText
							end,
						},
						statusText = {
							name = "Status text",
							desc = "AFK/DND/Corpse/Ghost text. Blank any text you don't want.",
							type = "toggle",
							order = 7,
							set = function()
								if (FixehTipSV.statusText) then
									FixehTipSV.statusText = nil
								else
									FixehTipSV.statusText = true
								end
							end,
							get = function()
								return FixehTipSV.statusText
							end,
						},
						invisibleLine1 = {
							name = " ",
							type = "description",
							order = 8,
						},
						targetOfTarget = {
							name = "Target of target",
							desc = "Tooltip target of target.",
							type = "toggle",
							order = 9,
							set = function()
								if (FixehTipSV.totEnabled) then
									FixehTipSV.totEnabled = nil
								else
									FixehTipSV.totEnabled = true
								end
							end,
							get = function()
								return FixehTipSV.totEnabled
							end,
						},
						totLevel = {
							name = "Level number",
							desc = "Adds level numbers to the target of target.",
							type = "toggle",
							order = 10,
							set = function()
								if (FixehTipSV.totLevel) then
									FixehTipSV.totLevel = nil
								else
									FixehTipSV.totLevel = true
								end
							end,
							get = function()
								return FixehTipSV.totLevel
							end,
						},
						targetedBy = {
							name = "Targeted by",
							desc = "How many people are targeting something in raid.",
							type = "toggle",
							order = 11,
							set = function()
								if (FixehTipSV.targetedBy) then
									FixehTipSV.targetedBy = nil
								else
									FixehTipSV.targetedBy = true
								end
							end,
							get = function()
								return FixehTipSV.targetedBy
							end,
						},
						invisibleLine2 = {
							name = " ",
							type = "description",
							order = 12,
						},
						totTargetText = {
							name = "Target text",
							type = "input",
							order = 13,
							set = function(_, input)
								FixehTipSV.totTargetText = input
							end,
							get = function()
								return FixehTipSV.totTargetText
							end,
						},
						totYouText = {
							name = "You text",
							type = "input",
							order = 14,
							set = function(_, input)
								FixehTipSV.totYouText = input
							end,
							get = function()
								return FixehTipSV.totYouText
							end,
						},
						targetedByText = {
							name = "Targeted by text",
							type = "input",
							order = 15,
							set = function(_, input)
								FixehTipSV.targetedByText = input
							end,
							get = function()
								return FixehTipSV.targetedByText
							end,
						},
						awayText = {
							name = "Away text",
							type = "input",
							order = 16,
							set = function(_, input)
								FixehTipSV.awayText = input
							end,
							get = function()
								return FixehTipSV.awayText
							end,
						},
						busyText = {
							name = "Busy text",
							type = "input",
							order = 17,
							set = function(_, input)
								FixehTipSV.busyText = input
							end,
							get = function()
								return FixehTipSV.busyText
							end,
						},
						corpseText = {
							name = "Corpse text",
							type = "input",
							order = 18,
							set = function(_, input)
								FixehTipSV.corpseText = input
							end,
							get = function()
								return FixehTipSV.corpseText
							end,
						},
						ghostText = {
							name = "Ghost text",
							type = "input",
							order = 19,
							set = function(_, input)
								FixehTipSV.ghostText = input
							end,
							get = function()
								return FixehTipSV.ghostText
							end,
						},
					},
				},
				font = {
					name = "Font",
					type = "group",
					order = 2,
					args = {
						fontName = {
							name = "Font",
							desc = "If you placed a font in the FixehTip folder with WoW still open, you need to restart the game before the font works.",
							type = "input",
							order = 1,
							set = function(_, input)
								FixehTipSV.font = input
								FixehTip.ApplyFont()
							end,
							get = function()
								return FixehTipSV.font
							end,
						},
						invisibleLine1 = {
							name = " ",
							type = "description",
							order = 2,
						},
						fontHeaderOutline = {
							name = "Header outline",
							type = "toggle",
							order = 3,
							set = function()
								if (FixehTipSV.headerOutline) then
									FixehTipSV.headerOutline = nil
								else
									FixehTipSV.headerOutline = true
								end
								FixehTip.ApplyFont()
							end,
							get = function()
								return FixehTipSV.headerOutline
							end,
						},
						fontOutline = {
							name = "Regular outline",
							type = "toggle",
							order = 4,
							set = function()
								if (FixehTipSV.fontOutline) then
									FixehTipSV.fontOutline = nil
								else
									FixehTipSV.fontOutline = true
								end
								FixehTip.ApplyFont()
							end,
							get = function()
								return FixehTipSV.fontOutline
							end,
						},
						headerSize = {
							name = "Header size",
							type = "input",
							order = 5,
							set = function(_, headerSize)
								FixehTipSV.headerSize = headerSize
								FixehTip.ApplyFont()
							end,
							get = function()
								return FixehTipSV.headerSize
							end,
						},
						fontSize = {
							name = "Regular size",
							type = "input",
							order = 6,
							set = function(_, fontSize)
								FixehTipSV.fontSize = fontSize
								FixehTip.ApplyFont()
							end,
							get = function()
								return FixehTipSV.fontSize
							end,
						},
					},
				},
				colors = {
					name = "Colors",
					type = "group",
					order = 3,
					args = {
						classNames = {
							name = "Class names",
							desc = "Class colored player names.",
							type = "toggle",
							order = 1,
							set = function()
								if (FixehTipSV.classNames) then
									FixehTipSV.classNames = nil
								else
									FixehTipSV.classNames = true
								end
							end,
							get = function()
								return FixehTipSV.classNames
							end,
						},
						classBorder = {
							name = "Class border",
							desc = "Class colored player border.",
							type = "toggle",
							order = 2,
							set = function()
								if (FixehTipSV.classBorder) then
									FixehTipSV.classBorder = nil
								else
									FixehTipSV.classBorder = true
								end
							end,
							get = function()
								return FixehTipSV.classBorder
							end,
						},
						classHealth = {
							name = "Class health",
							desc = "Class colored player health.",
							type = "toggle",
							order = 3,
							set = function()
								if (FixehTipSV.classHealth) then
									FixehTipSV.classHealth = nil
								else
									FixehTipSV.classHealth = true
								end
							end,
							get = function()
								return FixehTipSV.classHealth
							end,
						},
						reactionBackground = {
							name = "Reaction background",
							desc = "Colors unit background by reaction.",
							type = "toggle",
							order = 4,
							set = function()
								if (FixehTipSV.reactionBackground) then
									FixehTipSV.reactionBackground = nil
								else
									FixehTipSV.reactionBackground = true
								end
							end,
							get = function()
								return FixehTipSV.reactionBackground
							end,
						},
						reactionBorder = {
							name = "Reaction border",
							desc = "Colors unit border by reaction.",
							type = "toggle",
							order = 5,
							set = function()
								if (FixehTipSV.reactionBorder) then
									FixehTipSV.reactionBorder = nil
								else
									FixehTipSV.reactionBorder = true
								end
							end,
							get = function()
								return FixehTipSV.reactionBorder
							end,
						},
						reactionHealth = {
							name = "Reaction health",
							desc = "Colors unit health by reaction.",
							type = "toggle",
							order = 6,
							set = function()
								if (FixehTipSV.reactionHealth) then
									FixehTipSV.reactionHealth = nil
								else
									FixehTipSV.reactionHealth = true
								end
							end,
							get = function()
								return FixehTipSV.reactionHealth
							end,
						},
						purpleGuild = {
							name = "Purple guild",
							desc = "Colors guild purple for players in your guild.",
							type = "toggle",
							order = 7,
							set = function()
								if (FixehTipSV.purpleGuild) then
									FixehTipSV.purpleGuild = nil
								else
									FixehTipSV.purpleGuild = true
								end
							end,
							get = function()
								return FixehTipSV.purpleGuild
							end,
						},
						itemColors = {
							name = "Item colors",
							desc = "Item quality colored background/border.",
							type = "toggle",
							order = 8,
							set = function()
								if (FixehTipSV.itemColors) then
									FixehTipSV.itemColors = nil
								else
									FixehTipSV.itemColors = true
								end
							end,
							get = function()
								return FixehTipSV.itemColors
							end,
						},
						invisibleLine1 = {
							name = " ",
							type = "description",
							order = 9,
						},
						backgroundColor = {
							name = "Background color",
							type = "color",
							hasAlpha = true,
							order = 10,
							set = function(_, r, g, b, a)
								FixehTipSV.background_r = r
								FixehTipSV.background_g = g
								FixehTipSV.background_b = b
								FixehTipSV.background_a = a
							end,
							get = function()
								return FixehTipSV.background_r, FixehTipSV.background_g,
								FixehTipSV.background_b, FixehTipSV.background_a
							end,
						},
						borderColor = {
							name = "Border color",
							type = "color",
							hasAlpha = true,
							order = 11,
							set = function(_, r, g, b, a)
								FixehTipSV.border_r = r
								FixehTipSV.border_g = g
								FixehTipSV.border_b = b
								FixehTipSV.border_a = a
							end,
							get = function()
								return FixehTipSV.border_r, FixehTipSV.border_g,
								FixehTipSV.border_b, FixehTipSV.border_a
							end,
						},
						healthColor = {
							name = "Health color",
							type = "color",
							hasAlpha = true,
							order = 12,
							set = function(_, r, g, b, a)
								FixehTipSV.health_r = r
								FixehTipSV.health_g = g
								FixehTipSV.health_b = b
								FixehTipSV.health_a = a
							end,
							get = function()
								return FixehTipSV.health_r, FixehTipSV.health_g,
								FixehTipSV.health_b, FixehTipSV.health_a
							end,
						},
					},
				},
				fade = {
					name = "Fade",
					type = "group",
					order = 4,
					args = {
						instantFade = {
							name = "Instant fade",
							type = "toggle",
							order = 1,
							set = function()
								if (FixehTipSV.instantFade) then
									FixehTipSV.instantFade = nil
								else
									FixehTipSV.instantFade = true
								end
							end,
							get = function()
								return FixehTipSV.instantFade
							end,
						},
					},
				},
				scale = {
					name = "Scale",
					type = "group",
					order = 5,
					args = {
						scale = {
							name = "Tooltip scale",
							type = "range",
							order = 1,
							min = 0.6,
							max = 2.0,
							step = 0.01,
							set = function(_, value)
								FixehTipSV.scale = value
							end,
							get = function()
								return FixehTipSV.scale
							end,
						},
					},
				},
				hide = {
					name = "Hide",
					type = "group",
					desc = "To hide the border, change the alpha to 0 in colors.",
					order = 6,
					args = {
						hideHealth = {
							name = "Health bar",
							desc = "Hides the health bar on units.",
							type = "toggle",
							order = 1,
							set = function()
								if (FixehTipSV.hideHealthBar) then
									FixehTipSV.hideHealthBar = nil
								else
									FixehTipSV.hideHealthBar = true
								end
							end,
							get = function()
								return FixehTipSV.hideHealthBar
							end,
						},
						inCombat = {
							name = "Tooltip in combat",
							desc = "Hides the Tooltip for units when you enter combat.",
							type = "toggle",
							order = 2,
							set = function()
								if (FixehTipSV.inCombat) then
									FixehTipSV.inCombat = nil
								else
									FixehTipSV.inCombat = true
								end
							end,
							get = function()
								return FixehTipSV.inCombat
							end,
						},
						shiftCombat = {
							name = "Show Tooltip with shift",
							desc = "When hiding the Tooltip in combat you can show it by holding shift.",
							type = "toggle",
							order = 3,
							set = function()
								if (FixehTipSV.shiftCombat) then
									FixehTipSV.shiftCombat = nil
								else
									FixehTipSV.shiftCombat = true
								end
							end,
							get = function()
								return FixehTipSV.shiftCombat
							end,
						},
					},
				},
			},
		},
		resetSettings = {
			name = "Reset settings",
			type = "group",
			order = 3,
			args = {
				reset = {
					name = "Reset settings",
					type = "execute",
					order = 1,
					func = function()
						FixehTipSV = nil
						FixehTip.SavedVariables()
						FixehTip.ApplyFont()
					end,
				},
			},
		},
	},
}

sort(TooltipLocations.Mouse)
sort(TooltipLocations.Default)

LibStub("AceConfig-3.0"):RegisterOptionsTable("FixehTip", FixehTipConfig)
LibStub("AceConfigDialog-3.0"):SetDefaultSize("FixehTip", 640, 540)
LibStub("AceConfigDialog-3.0"):AddToBlizOptions("FixehTip")

SLASH_FixehTip1 = "/fixehtip"
function SlashCmdList.FixehTip()
	LibStub("AceConfigDialog-3.0"):Open("FixehTip")
end
